diff --git a/dumux/common/properties.hh b/dumux/common/properties.hh
index bc7af537b732bec3039d66fc55b2e36d2128bcac..b216967ed283f52d6b6a68cc20f0584307987ef7 100644
--- a/dumux/common/properties.hh
+++ b/dumux/common/properties.hh
@@ -123,6 +123,10 @@ DONT_EMIT_CLANG_GRIDGEOMETRY_WARNING."
 template<class TypeTag, class MyTypeTag>
 struct [[deprecated("Use GridGeometry instead.")]] FVGridGeometry { using type = UndefinedProperty; }; //!< The type of the global finite volume geometry
 
+// TODO: Remove deprecated property EnableFVGridGeometryCache after 3.1
+template<class TypeTag, class MyTypeTag>
+struct [[deprecated("Use EnableGridGeometryCache instead.")]] EnableFVGridGeometryCache { using type = UndefinedProperty; };           //!< specifies if geometric data is saved (faster, but more memory consuming)
+
 // Dumux 3.1 changes the property `FVGridGeometry` to `GridGeometry`.
 // For ensuring backward compatibility, it is necessary to set the default value
 // of the new property to the old one, see the discussion in MR 1647.
@@ -146,10 +150,24 @@ struct GridGeometry
     using type = typename GridGeometryHelper<TypeTag, typename FVGridGeometry<TypeTag, MyTypeTag>::type>::type;
 };
 
-#pragma GCC diagnostic pop
+template<class TypeTag, bool hasParentTypeTag>
+struct EnableGridGeometryCacheHelper
+{ using type = UndefinedProperty; };
 
-template<class TypeTag, class MyTypeTag>
-struct EnableFVGridGeometryCache { using type = UndefinedProperty; };           //!< specifies if geometric data is saved (faster, but more memory consuming)
+template<class TypeTag>
+struct EnableGridGeometryCacheHelper<TypeTag, false>
+{
+    // fallback
+    static constexpr bool value = getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>();
+};
+
+// only use the fallback (EnableFVGridGeometryCache) if none
+// of the TypeTags define EnableGridGeometryCache
+template <class TypeTag, class MyTypeTag>
+struct EnableGridGeometryCache : public EnableGridGeometryCacheHelper<TypeTag, Detail::hasParentTypeTag<MyTypeTag>(int{})>
+{};
+
+#pragma GCC diagnostic pop
 
 template<class TypeTag, class MyTypeTag>
 struct VolumeVariables { using type = UndefinedProperty; };                     //!< The secondary variables within a sub-control volume
diff --git a/dumux/discretization/box.hh b/dumux/discretization/box.hh
index 3ac7189877cb8b1babec82fad0b8c6cfa333d788..bb3787685cef4e54b53d28fb1a68180978722200 100644
--- a/dumux/discretization/box.hh
+++ b/dumux/discretization/box.hh
@@ -63,7 +63,7 @@ template<class TypeTag>
 struct FVGridGeometry<TypeTag, TTag::BoxModel>
 {
 private:
-    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>();
+    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableGridGeometryCache>();
     using GridView = GetPropType<TypeTag, Properties::GridView>;
     using Scalar = GetPropType<TypeTag, Properties::Scalar>;
 public:
diff --git a/dumux/discretization/ccmpfa.hh b/dumux/discretization/ccmpfa.hh
index 8268d077ff1ffdf73b7d6c399e3fef50ff89bec6..73b175cbaebc3b8e6c49093115d30105d7a6482a 100644
--- a/dumux/discretization/ccmpfa.hh
+++ b/dumux/discretization/ccmpfa.hh
@@ -114,7 +114,7 @@ private:
     using NodalIndexSet = GetPropType<TypeTag, Properties::DualGridNodalIndexSet>;
     using Traits = CCMpfaFVGridGeometryTraits<GridView, NodalIndexSet, PrimaryIV, SecondaryIV>;
 public:
-    using type = CCMpfaFVGridGeometry<GridView, Traits, getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>()>;
+    using type = CCMpfaFVGridGeometry<GridView, Traits, getPropValue<TypeTag, Properties::EnableGridGeometryCache>()>;
 };
 #pragma GCC diagnostic pop
 
diff --git a/dumux/discretization/cctpfa.hh b/dumux/discretization/cctpfa.hh
index b81a0779103753b95d3c6e7fa3c3fd8f4bf585b9..c43fb7186d58513ea1b13c7455d4de5b9e196e53 100644
--- a/dumux/discretization/cctpfa.hh
+++ b/dumux/discretization/cctpfa.hh
@@ -62,7 +62,7 @@ template<class TypeTag>
 struct FVGridGeometry<TypeTag, TTag::CCTpfaModel>
 {
 private:
-    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>();
+    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableGridGeometryCache>();
     using GridView = GetPropType<TypeTag, Properties::GridView>;
 public:
     using type = CCTpfaFVGridGeometry<GridView, enableCache>;
diff --git a/dumux/discretization/fvproperties.hh b/dumux/discretization/fvproperties.hh
index f1a796b692bb7ea4c641cdb296de981ac964e8e2..79f157bb54be1443d85cba00ec9406fe81142bfb 100644
--- a/dumux/discretization/fvproperties.hh
+++ b/dumux/discretization/fvproperties.hh
@@ -55,9 +55,17 @@ public:
     using type = FVGridVariables<GG, GVV, GFVC>;
 };
 
+// Dumux 3.1 changes the property `EnableFVGridGeometryCache` to `EnableGridGeometryCache`.
+// For ensuring backward compatibility on the user side, it is necessary to
+// stick to the old name for the specializations, see the discussion in MR 1647.
+// Use diagnostic pragmas to prevent the emission of a warning message.
+// TODO after 3.1: Rename to EnableGridGeometryCache, remove the pragmas and this comment.
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 //! We do not store the FVGeometry by default
 template<class TypeTag>
 struct EnableFVGridGeometryCache<TypeTag, TTag::FiniteVolumeModel> { static constexpr bool value = false; };
+#pragma GCC diagnostic pop
 
 //! We do not store the volume variables by default
 template<class TypeTag>
diff --git a/dumux/discretization/staggered/freeflow/properties.hh b/dumux/discretization/staggered/freeflow/properties.hh
index 78e5e4ebd30b8c12916274ccf45d28feaa29c2f2..1c9f1b12ff4f232b6fb4a074f6d26f49f28938e5 100644
--- a/dumux/discretization/staggered/freeflow/properties.hh
+++ b/dumux/discretization/staggered/freeflow/properties.hh
@@ -89,7 +89,7 @@ struct FVGridGeometry<TypeTag, TTag::StaggeredFreeFlowModel>
 {
 private:
     static constexpr auto upwindSchemeOrder = getPropValue<TypeTag, Properties::UpwindSchemeOrder>();
-    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>();
+    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableGridGeometryCache>();
     using GridView = GetPropType<TypeTag, Properties::GridView>;
     using Traits = StaggeredFreeFlowDefaultFVGridGeometryTraits<GridView, upwindSchemeOrder>;
 public:
diff --git a/dumux/multidomain/facet/box/properties.hh b/dumux/multidomain/facet/box/properties.hh
index ae9b68fc7b3b0b174c2a37e5962bacffa359467e..25b92ec27704c46d3c20bccb598aa40eebefbf99 100644
--- a/dumux/multidomain/facet/box/properties.hh
+++ b/dumux/multidomain/facet/box/properties.hh
@@ -88,7 +88,7 @@ template<class TypeTag>
 struct FVGridGeometry<TypeTag, TTag::BoxFacetCouplingModel>
 {
 private:
-    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>();
+    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableGridGeometryCache>();
     using GridView = GetPropType<TypeTag, Properties::GridView>;
     using Scalar = GetPropType<TypeTag, Properties::Scalar>;
 public:
diff --git a/dumux/porousmediumflow/boxdfm/model.hh b/dumux/porousmediumflow/boxdfm/model.hh
index 84388e596169f90109c6b4d50a475ff78f950921..df5250eaea4e3d3b87562f380840b3b7171d167e 100644
--- a/dumux/porousmediumflow/boxdfm/model.hh
+++ b/dumux/porousmediumflow/boxdfm/model.hh
@@ -52,7 +52,7 @@ template<class TypeTag>
 struct FVGridGeometry<TypeTag, TTag::BoxDfmModel>
 {
 private:
-    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableFVGridGeometryCache>();
+    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableGridGeometryCache>();
     using GridView = GetPropType<TypeTag, Properties::GridView>;
     using Scalar = GetPropType<TypeTag, Properties::Scalar>;
 public:
diff --git a/dumux/discretization/cellcentered/mpfa/fvelementgeometry.hh b/dumux/discretization/cellcentered/mpfa/fvelementgeometry.hh
index 7beedaa45f7095575e0bc2e81b4bfa2a7d061f08..25357ab3c83fceb2bb1700152d4393c354450604 100644
--- a/dumux/discretization/cellcentered/mpfa/fvelementgeometry.hh
+++ b/dumux/discretization/cellcentered/mpfa/fvelementgeometry.hh
@@ -42,10 +42,10 @@ namespace Dumux {
  *        This builds up the sub control volumes and sub control volume faces
  *        for each element in the local scope we are restricting to, e.g. stencil or element.
  * \tparam GG the finite volume grid geometry type
  * \tparam enableFVGridGeometryCache if the grid geometry is cached or not
  * \note This class is specialized for versions with and without caching the fv geometries on the grid view
  */
-template<class GG, bool EnableFVGridGeometryCache>
+template<class GG, bool enableGridGeometryCache>
 class CCMpfaFVElementGeometry;
 
 /*!
@@ -42,10 +42,10 @@ namespace Dumux {
  *        for each element in the local scope we are restricting to, e.g. stencil or element.
  * \tparam GG the finite volume grid geometry type
- * \tparam enableFVGridGeometryCache if the grid geometry is cached or not
+ * \tparam enableGridGeometryCache if the grid geometry is cached or not
  * \note This class is specialized for versions with and without caching the fv geometries on the grid view
  */